@@ -37,23 +37,35 @@
 
 #ifndef __PLUGIN_H__
 #define __PLUGIN_H__
+#include <npapi.h>
+#include <npruntime.h>
+#include "npupp.h"
 #include <X11/Xlib.h>
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib-lowlevel.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+#ifdef HAVE_GCONF
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <gconf/gconf-value.h>
-#include <glib.h>
-#include "pluginbase.h"
-#include "nsScriptablePeer.h"
-#include "plugin_list.h"
-#ifdef HAVE_GETTEXT
-# include <libintl.h>
-# define _(x) (gettext(x))
-#else
-# define _(x) (x)
 #endif
 
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
+#include "plugin_list.h"
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#endif
+
+gpointer init_preference_store();
+gboolean read_preference_bool(gpointer store, const gchar * key);
+gint read_preference_int(gpointer store, const gchar * key);
+void release_preference_store(gpointer store);
+gchar *gmp_tempname(gchar * path, const gchar * name_template);
+
 // JavaScript Playstates
 #define STATE_UNDEFINED     0
 #define STATE_STOPPED       1
@@ -77,14 +89,25 @@
 #define DEBUG_LEVEL		"/apps/gecko-mediaplayer/preferences/debug_level"
 
 
-class nsPluginInstance:public nsPluginInstanceBase {
+class CPlugin {
+  private:
+    NPWindow * m_Window;
+    NPStream *m_pNPStream;
+    NPBool mInitialized;
+    NPObject *m_pScriptableObject;
+    NPObject *m_pScriptableObjectControls;
+
   public:
-    nsPluginInstance(NPP aInstance);
-    virtual ~ nsPluginInstance();
+     CPlugin(NPP pNPInstance);
+    ~CPlugin();
 
     NPBool init(NPWindow * aWindow);
     void shut();
     NPBool isInitialized();
+    int16 handleEvent(void *event);
+
+    NPObject *GetScriptableObject();
+    NPObject *GetScriptableObjectControls();
 
     NPError GetValue(NPPVariable variable, void *value);
     NPError SetWindow(NPWindow * aWindow);
@@ -95,8 +118,6 @@ class nsPluginInstance:public nsPluginInstanceBase {
     int32 Write(NPStream * stream, int32 offset, int32 len, void *buffer);
 
 
-    nsScriptablePeer *getScriptablePeer();
-    nsControlsScriptablePeer *getControlsScriptablePeer();
 
     void Play();
     void Pause();
@@ -127,16 +148,12 @@ class nsPluginInstance:public nsPluginInstanceBase {
     void SetOnMouseOut(const char *event);
     void SetOnMouseOver(const char *event);
     void SetOnDestroy(const char *event);
-    
+
   private:
-     NPBool mInitialized;
 
-    gint mX, mY;
+     gint mX, mY;
     gint mWidth, mHeight;
 
-    nsScriptablePeer *mScriptablePeer;
-    nsControlsScriptablePeer *mControlsScriptablePeer;
-
   public:
      Window mWindow;
     NPP mInstance;
@@ -160,6 +177,7 @@ class nsPluginInstance:public nsPluginInstanceBase {
     gboolean disable_context_menu;
     gboolean disable_fullscreen;
     gboolean debug;
+    gint show_controls;
     gchar *name;
     gchar *console;
     gchar *controls;
@@ -175,15 +193,15 @@ class nsPluginInstance:public nsPluginInstanceBase {
 
     // options
     gint debug_level;
-    
+
     // tv options
     gchar *tv_device;
     gchar *tv_driver;
     gchar *tv_input;
     gint tv_width;
     gint tv_height;
-    
-    
+
+
 };
 
 #endif                          // __PLUGIN_H__
