@@ -41,11 +41,7 @@
 #include <glib/gstdio.h>
 #include <stdio.h>
 #include <string.h>
-
-#ifndef HAVE_MEMMEM
-void *memmem(const void *haystack, const size_t haystack_len,
-	     const void *needle, const size_t needle_len);
-#endif
+#include "memmem_compat.h"
 
 
 typedef struct _ListItem {
